#!/bin/ksh

# PTF Standard Edition Install

echo "WebSphere Application Server 3.5, Standard Edition PTF 2"

OS_NAME=`uname`

if [[ "$OS_NAME" = "AIX" ]]  ; then
   DELTA_JAR="was35_std_ptf_2_AIX.jar"
   DELTA_LOG="was35_std_ptf_2_AIX.log"
   IHS_PTF="IHS_ptf_aix.zip"
   JAVA_PTF="java_ptf_aix.zip"
   IHS_DIR="/usr/HTTPServer"
   IKEYMAN="usr/bin/ikeyman"
elif [[ "$OS_NAME" = "SunOS" || "$OS_NAME" = "Solaris" ]] ; then
   DELTA_JAR="was35_std_ptf_2_SUN.jar"
   DELTA_LOG="was35_std_ptf_2_SUN.log"
   IHS_PTF="IHS_ptf_sun.zip"
   JAVA_PTF="java_ptf_sun.zip"
   IHS_DIR="/opt/IBMHTTPD"
   IKEYMAN="usr/bin/ikeyman"
elif [[ "$OS_NAME" = "HP-UX" ]]  ; then
   DELTA_JAR="was35_std_ptf_2_HP.jar"
   DELTA_LOG="was35_std_ptf_2_HP.log"
   JAVA_PTF="java_ptf_hp.zip"
   HP_JDK_PATCH="hp_jdk_patch.zip"
   IHS_PTF="IHS_ptf_hp.zip"
   IHS_DIR="/opt/HTTPServer"
   IKEYMAN="usr/bin/ikeyman"
else
   echo "Unspported platform: $OS_NAME"
   echo "Exiting ..."
   exit 1
fi

BACKUP_JAR="was35_ptf_2_backup.jar"
UINSTALL_FILE="uninstall_ptf_2.sh"
LOG_FILE="was35_ptf_2.log"
IHS_LOG_FILE="ihs_ptf_2.log"
JAVA_LOG_FILE="jdk_ptf_2.log"

##  echo "OS_NAME      = $OS_NAME"
##  echo "DELTA_JAR    = $DELTA_JAR"
##  echo "DELTA_LOG    = $DELTA_LOG"
##  echo "IHS_PTF      = $IHS_PTF"
##  echo "JAVA_PTF     = $JAVA_PTF"
##  echo "IHS_DIR      = $IHS_DIR"

# Unzipping the JDK PTF

   while :
   do
   {
    echo "Please enter the WebSphere root directory"
    read WAS_DIR
    if [[ "${WAS_DIR}" = "" ]]
    then
       continue
    fi
      
    if [[ ! -d ${WAS_DIR} || ! -f ${WAS_DIR}/properties/com/ibm/websphere/product.xml  ]]
       then
         {
            echo
            echo "Unable to locate file: ${WAS_DIR}/properties/com/ibm/websphere/product.xml"
            echo 
            continue
         }
     fi

     break
    }
    done

  if [[ "$OS_NAME" = "AIX" ]] ; then 
    unzip -o $JAVA_PTF -d $WAS_DIR >> $WAS_DIR/logs/$JAVA_LOG_FILE
  fi

## Install HP JDK Patch
  if [[ "$OS_NAME" = "HP-UX" ]] ; then
      echo "Installing HP JDK Patch ..."
      unzip -o $HP_JDK_PATCH -d $WAS_DIR >> $WAS_DIR/logs/$JAVA_LOG_FILE
      echo "Done ... installing HP JDK Patch."
  fi

#Unzipping the IHS PTF
  while :
  do
  {
    echo "Please enter whether you want to install IHS WebServer PTF (y/n)"
    read IHS_INSTALL
    if [[ "${IHS_INSTALL}" = "" ]]
    then
       continue
    fi
      
    if [[ "$IHS_INSTALL" != "y" && "$IHS_INSTALL" != "n" ]]
       then
         {
            echo
            echo "Please enter y for Yes or n for No"
            echo 
            continue
         }
     fi

     break
   }
   done

if [[ "$IHS_INSTALL" = "y" ]] ; then
   unzip -o $IHS_PTF -x $IKEYMAN -d $IHS_DIR >> $WAS_DIR/logs/$IHS_LOG_FILE
   unzip -oj $IHS_PTF $IKEYMAN -d /usr/bin/ >> $WAS_DIR/logs/$IHS_LOG_FILE 
fi

#Installing the WAS PTF

export JAVA_HOME=$WAS_DIR/java
if [[ "$OS_NAME" = "AIX" ]]  ; then
export PATH=$JAVA_HOME/jre/sh:$JAVA_HOME/sh:$PATH
elif [[ "$OS_NAME" = "SunOS" || "$OS_NAME" = "Solaris" ]] ; then
export PATH=$JAVA_HOME/bin:$PATH
elif [[ "$OS_NAME" = "HP-UX" ]]  ; then
export PATH=$JAVA_HOME/bin:/usr/sbin:$PATH
fi

echo "Installing the WebSphere Application Server 3.5 PTF"

java -jar $DELTA_JAR -TargetDir $WAS_DIR -backupJar $WAS_DIR/$BACKUP_JAR -log $WAS_DIR/logs/$LOG_FILE

# add execute permission to uninstall script.
#chmod 711 ${WAS_DIR}/$UINSTALL_FILE

# Update the samples in the Webservers doc root
while :
do
{
     echo "In order to update the WebSphere Application Server Samples"
     echo "the currently configured WebServer's doc root must be specified" 
     echo "or press enter to skip upgrading the samples."
     echo "Eg. /opt/IBMHTTPD/htdoc"

     echo "Please enter your webserver's doc root path" 
     read DOC_ROOT
	if [[ "${DOC_ROOT}" = "" ]]
	then
	   break
	fi

	echo "Is this correct (y/n): $DOC_ROOT"
	read CONFIRM
	if [[ "$CONFIRM" != "y" ]]
	   then
		 {
			echo
			echo "Please enter y for Yes or n for No"
			echo 
			continue
		 }
	 fi
       if [[ ! -d $DOC_ROOT ]] ; then
          echo "No such directory: $DOC_ROOT"
          echo " "
          continue 
       fi
	 break
}
done

if [[ "$CONFIRM" = "y" ]] ; then
   cp -pR $WAS_DIR/WSsamplesIDB $DOC_ROOT
   cp -pR $WAS_DIR/WSsamples $DOC_ROOT
   cp -pR $WAS_DIR/theme $DOC_ROOT
   chmod -R 755 $DOC_ROOT
fi

#End install 
